.. |salt| replace:: `Salt`_
.. _salt: https://saltproject.io

.. |saltrepo| replace:: `Salt repository`_
.. _Salt repository: https://github.com/saltstack/salt

.. |salt-extension| replace:: `salt-extension`_
.. _salt-extension: https://www.youtube.com/watch?v=hhomJkwxK3Q
